@@ -583,6 +583,8 @@ sub fetch_color {
 		allocate_color($color_name,$rgb_text,$color_table,$im);
 		stop_timer("colorfetch");
 		return $color_table->{$color_name};
+	} elsif (my $default_color = fetch_conf("default_color")) {
+		return $color_table->{$default_color};
 	} else {
 		fatal_error("color","undefined",$color_name);
 	}
