@@ -69,6 +69,7 @@ use Circos::Error;
 our %CONF;
 our $DIMS;
 
+our $COUNTER;
 
 # -------------------------------------------------------------------
 # Return the configuration hash leaf for a parameter path.
@@ -367,8 +368,9 @@ sub merge_top_hashes {
 						radius     => { pass => qr/tick/ },
 						axis       => { pass => qr/axes/ },
             param      => { pass => qr/_root/},
+						post_increment_counter => { pass => qr/plot/ },
 					 };
-	
+
 	sub check_multivalues {
 		my ($root,$root_name,$level) = @_;
 
@@ -401,7 +403,6 @@ sub merge_top_hashes {
 	    }
 			#printinfo($level,$key,$value);
 		}
-
 		for my $key (keys %$root) {
 	    my $value = $root->{$key};
 	    if (ref $value eq "HASH" ) {
@@ -429,6 +430,7 @@ sub postprocess_values {
 	    } else {
 				#printinfo("conf_iterate","value",$key,$value);
 				if($value =~ /undef/i) {
+					#delete $node->{$key};
 					$node->{$key} = undef;
 				}
 			}
@@ -458,17 +460,26 @@ sub conf_iterate {
 }
 
 sub set_counters {
-	my ($node,@paramfn) = @_;
+	my ($node,$parent_node_name,@paramfn) = @_;
 	my %set_counter_names;
 	for my $paramfn (@paramfn) {
 		my ($param,$fn) = @{$paramfn}{qw(param fn)};
-		if (my $value = $node->{$param}) {
-	    for my $counter_txt (split(",",$value)) {
-				my ($counter,$incr) = split(":",$counter_txt);
+		next if ! defined $node->{$param};
+		my @values      = make_list($node->{$param});
+		for my $value (grep(defined $_,@values)) {
+			for my $counter_txt (split(",",$value)) {
+				my ($counter,$incr);
+				if($counter_txt =~ /:/) {
+					($counter,$incr) = split(":",$counter_txt);
+				} else {
+					$counter = $parent_node_name;
+					$incr    = $counter_txt;
+				}
+				#printinfo($node,$parent_node_name,$counter,$incr);
 				$fn->($counter,$incr);
 				$set_counter_names{$counter}++;
-	    }
-		}	
+			}
+		}
 	}
 	return %set_counter_names;
 }
@@ -504,6 +515,7 @@ sub repopulateconfiguration {
 
   my %set_counter_names = set_counters(
 																			 $node,
+																			 $parent_node_name,
 																			 { param=>"init_counter",				   fn=>\&init_counter 	   },
 																			 { param=>"pre_increment_counter", fn=>\&increment_counter },
 																			 { param=>"pre_set_counter",       fn=>\&set_counter       },
@@ -542,13 +554,15 @@ sub repopulateconfiguration {
 
   %set_counter_names = set_counters(
 																		$node,
+																		$parent_node_name,
 																		{ param=>"post_increment_counter", fn=>\&increment_counter },
 																		{ param=>"post_set_counter",       fn=>\&set_counter       },
 																	 );
 
   # default post increment counter
 	if (ref $node && defined $parent_node_name) {
-		increment_counter($parent_node_name,1) if ! $set_counter_names{$parent_node_name};
+		my $default_increment = defined $COUNTER->{$parent_node_name}{increment} ? $COUNTER->{$parent_node_name}{increment} : 1;
+		increment_counter($parent_node_name,$default_increment) if ! $set_counter_names{$parent_node_name};
 	}
 
 }
@@ -792,7 +806,8 @@ sub increment_counter {
   my ($counter,$value) = @_;
   init_counter($counter,0);
 	if (defined $value) {
-		$CONF{counter}{$counter} += $value;
+		$COUNTER->{$counter}{increment}  = $value;
+		$CONF{counter}{$counter}        += $value;
 		printdebug_group("counter","incrementing counter",$counter,$value,"now",get_counter($counter));
 	}
 }
@@ -812,9 +827,9 @@ sub set_counter {
 		if (! $seen{$counter}++) {
 			if (defined $value) {
 				$CONF{counter}{$counter} = $value;
+				printdebug_group("counter","init counter",$counter,"with value",$value,"new value",get_counter($counter));
 			}
 		}
-		printdebug_group("counter","init counter",$counter,"with value",$value,"new value",get_counter($counter));
 	}
 }
 
