@@ -126,7 +126,7 @@ $ERROR{configuration} =
    missing => "file(error/configuration.missing.txt)",
    bad_parameter_type => "You attempted to reference a configuration parameter group with name [%s], but it is not defined",
    defined_twice => "Parameter [%s] of type [%s] is defined twice. Some parameters can have multiple values, but not this one.",
-   multiple_defn_in_list => "Configuration value [%s] defines parameter [%s] more than once. This is not allowed.",
+   multiple_defn_in_list => "Configuration value [%s] defines parameter [%s] more than once. This is not allowed. If you want to override a parameter included from a file, use * suffix (e.g. file* = myfile.png)",
    multivalue => "Configuration parameter [%s] in parent block [%s] has been defined more than once in the block shown above, and has been interpreted as a list. This is not allowed. Did you forget to comment out an old value of the parameter?",
    unsupported_parameter => "Parameter [%s] of type [%s] is not supported.",
    bad_pointer => "Problem with variable lookup in configuration file. You referenced variable [%s] (seen as %s) in another parameter, but this variable is not defined.",
@@ -197,7 +197,7 @@ $ERROR{io} =
 
 $ERROR{parsedata} =
 	{
-	 bad_options => "Error parsing data point options. Saw parameter assignment [%s] but expected it to be in the format x=y.",
+	 bad_options => "Error parsing data point options. Saw parameter assignment [%s] but expected it to be in the format x=y. Make sure that you're not using a data file with values for a track that does not require values.",
 	 bad_csv     => "Could not parse comma-delimited list [%s] because of unbalanced parentheses [%d]. Correct syntax is x=(1,2),y=3, which is split along the second comma to x=(1,2) and y=3.",
 	 bad_field_format => "The field [%s] did not have the expected format. The value [%s] was expected to be a [%s]. This was seen in file [%s] on line\n\n%s",
 	 no_such_re => "You tried to test the number [%s] with a number regular expression of type [%s] but this type is not defined. Regexp::Common module returned error [%s]",
@@ -208,8 +208,11 @@ $ERROR{parsedata} =
  
 $ERROR{warning} =
 {
-    general => "%s",
-    paranoid => "Circos produced a warning and quit because you are running it in paranoid mode. The warning does not nececessarily mean that something is wrong - Circos was likely trying to guess a parameter or massage data to fit the figure.\nTo change this setting, use -noparanoid flag or change the 'paranoid' parameter in etc/housekeeping.conf to 'paranoid=no'.",
+ general => "%s",
+ data_range_exceeded => "Data point of type [%s] [%s] extended past end of ideogram [%s %s]. This data point will be [%s].",
+ track_has_no_file => "Track id [%s] of type [%s] has no file definition. This is alright if you're using the track for side-effects like axes and backgrounds.",
+ track_has_no_type => "Track id [%s] has no type definition. This is alright if you're using the track for side-effects like axes and backgrounds.",
+ paranoid => "Circos produced a warning and quit because you are running it in paranoid mode. The warning does not nececessarily mean that something is wrong - Circos was likely trying to guess a parameter or massage data to fit the figure.\nTo change this setting, use -noparanoid flag or change the 'paranoid' parameter in etc/housekeeping.conf to 'paranoid=no'.",
 };
 
 $ERROR{track} =
@@ -247,6 +250,7 @@ $ERROR{map} =
 
 $ERROR{data} =
 {
+    data_range_exceeded => "Data point of type [%s] [%s] extended past end of ideogram [%s %s]. You've set data_out_of_range=fatal, so Circos is quitting. See etc/housekeeping.conf for other options of this parameter.",
     bad_karyotype_format => "Could not parse line from karyotype file [%s].",
     bad_karyotype_band_format => "Could not parse band line from karyotype file. The line\n\n  %s\n\nis missing fields. The correct format is\n\n  band chr_name band_name band_label start end color\n",
     malformed_span => "There was a problem initializing a span. Saw start [%s] > end [%s].",
@@ -261,7 +265,9 @@ $ERROR{data} =
 
 $ERROR{ticks} =
 	{
-	 too_many => "You are trying to draw [%s] ticks on ideogram [%s]. This is a lot of ticks and will take a very long time. Make sure that chromosomes_units parameter is set and read this tutorial\n\nhttp://www.circos.ca/documentation/tutorials/ticks_and_labels/basics/\n\nTo change the maximum tick number, adjust 'max_ticks' in etc/housekeeping.conf",
+	 bad_suffix => "You used the suffix [%s] in the string [%s]. This suffix is not defined. Use one of K, G, M, or T (or Kb, Gb, Mb, Tb)",
+	 unparsable => "The string [%s] cannot be parsed into a numerical quantity.",
+	 too_many   => "You are trying to draw [%s] ticks on ideogram [%s]. This is a lot of ticks and will take a very long time. Make sure that chromosomes_units parameter is set and read this tutorial\n\nhttp://www.circos.ca/documentation/tutorials/ticks_and_labels/basics/\n\nTo change the maximum tick number, adjust 'max_ticks' in etc/housekeeping.conf",
 };
 
 $ERROR{function} =
@@ -291,67 +297,69 @@ $ERROR{system} =
 
 $ERROR{support} =
 {
-    googlegroup=>"If you are having trouble debugging this error, use this tutorial to learn how to use the debugging facility\n http://www.circos.ca/tutorials/lessons/configuration/debugging\nIf you're still stumped, get support in the Circos Google Group\n  http://groups.google.com/group/circos-data-visualization",
+    googlegroup=>"If you are having trouble debugging this error, first read the best practices tutorial for helpful tips that address many common problems\n http://www.circos.ca/documentation/tutorials/reference/best_practices\nThe debugging facility is helpful to figure out what's happening under the hood\n http://www.circos.ca/tutorials/lessons/configuration/debugging\nIf you're still stumped, get support in the Circos Google Group\n http://groups.google.com/group/circos-data-visualization",
 };
 
 sub error {
     my ($cat,$errorid,@args) = @_;
     my $error_text = $ERROR{$cat}{$errorid};
     if(! defined $error_text) {
-	fatal_error("system","bad_error_name",$cat,$errorid);
+			fatal_error("system","bad_error_name",$cat,$errorid);
     }
     if($error_text =~ /file\((.*)\)/) {
-	my $file = Circos::Utils::locate_file(file=>$1,name=>"error file",return_undef=>1);
-	if($file && open(F,$file)) {
-	    $error_text = join("",<F>);
-	    close(F);
-	} else {
-	    $error_text = "...error text from [$1] could not be read...";
-	}
+			my $file = Circos::Utils::locate_file(file=>$1,name=>"error file",return_undef=>1);
+			if($file && open(F,$file)) {
+				$error_text = join("",<F>);
+				close(F);
+			} else {
+				$error_text = "...error text from [$1] could not be read...";
+			}
     }
     my (@text,$format);
     my $undef_text = Circos::Configuration::fetch_conf("debug_undef_text") || "_undef_";
     @args = map { defined $_ ? $_ : $undef_text } @args;
     if($cat eq "warning") {
-	if(Circos::Configuration::fetch_conf("paranoid")) {
-	    @text = ("*** CIRCOS WARNING ***",
-		     $GROUPERROR{$cat} ? uc $GROUPERROR{$cat} : $EMPTY_STR,
-		     sprintf($error_text,@args));
-	    $format = 1;
-	} else {
-	    printdebug_group("!circoswarning",uc $GROUPERROR{$cat},sprintf($error_text,@args));
-	    return;
-	}
+			if(Circos::Configuration::fetch_conf("paranoid")) {
+				@text = ("WARNING *** "
+								 .
+								 ($GROUPERROR{$cat} ? uc $GROUPERROR{$cat} : $EMPTY_STR)
+								 .
+								 sprintf($error_text,@args));
+				#$format = 1;
+			} else {
+				printdebug_group("!circoswarning",uc $GROUPERROR{$cat},sprintf($error_text,@args));
+				return;
+			}
     } else {
-	@text = ("*** CIRCOS ERROR ***",
-		 $GROUPERROR{$cat} ? uc $GROUPERROR{$cat} : $EMPTY_STR,
-		 sprintf($error_text,@args),
-		 $ERROR{support}{googlegroup},
-		 "",
-		 "Stack trace:",
-	    );
-	$format = 1;
+			@text = ("*** CIRCOS ERROR ***",
+							 $GROUPERROR{$cat} ? uc $GROUPERROR{$cat} : $EMPTY_STR,
+							 sprintf($error_text,@args),
+							 $ERROR{support}{googlegroup},
+							 "",
+							 "Stack trace:",
+							);
+			$format = 1;
     }
     if($format) {
-	my @text_fmt;
-	for my $t (@text) {
-	    for my $line (split(/\n/, $t)) {
-		if ($line =~ /^\s/) {
-		    push @text_fmt, Text::Format->new({leftMargin=>6,columns=>80,firstIndent=>0})->paragraphs($line);
-		} else {
-		    push @text_fmt, Text::Format->new({leftMargin=>2,columns=>80,firstIndent=>0})->paragraphs($line);
-		}
-	    }
-	}
-	print "\n" . join("\n", @text_fmt);
+			my @text_fmt;
+			for my $t (@text) {
+				for my $line (split(/\n/, $t)) {
+					if ($line =~ /^\s/) {
+						push @text_fmt, Text::Format->new({leftMargin=>6,columns=>80,firstIndent=>0})->paragraphs($line);
+					} else {
+						push @text_fmt, Text::Format->new({leftMargin=>2,columns=>80,firstIndent=>0})->paragraphs($line);
+					}
+				}
+			}
+			print "\n" . join("\n", @text_fmt);
     } else {
-	print join(" ",@text)."\n";
+			print join(" ",@text)."\n";
     }
-}
+	}
 
 sub fatal_error {
-    error(@_);
-    confess;
+	error(@_);
+	confess;
 }
 
 1;
