@@ -295,7 +295,10 @@ sub fetch_variable {
 		if(fetch_conf("skip_missing_expression_vars")) {
 	    $value = undef;
 		} else {
-	    fatal_error("rules","no_such_field",$expr,$var,Dumper($datum));
+			$value = seek_parameter($var.$varnum,@$param_path);
+			if(! defined $value) {
+				fatal_error("rules","no_such_field",$expr,$var,Dumper($datum));
+			}
 		}
 	}
 	#$value = Circos::unit_strip($value);
