@@ -66,10 +66,12 @@ our @type_ok = qw(scatter line histogram heatmap highlight tile text connector);
 
 sub make_tracks {
 	my ($conf_leaf,$track_default,$type) = @_;
+
 	my @tracks;
 	# If the tracks are stored as named blocks, associate the
 	# name with the __id parameter for each track. Otherwise, generate __id
 	# automatically using an index
+
 	if (ref $conf_leaf eq "HASH") {
 		# Could be one or more named blocks, or a single unnamed block.
 		# If each value is a hash, then assume that we have named blocks
@@ -140,7 +142,8 @@ sub make_tracks {
 		}
 		$t->{file} ||= seek_parameter("file",$track_default);
 		if (! defined $t->{file}) {
-			fatal_error("track","no_file",$t->{type},$t->{id},Dumper($t));
+			#fatal_error("track","no_file",$t->{type},$t->{id},Dumper($t));
+			error("warning","track_has_no_file",$t->{id},$t->{type});
 		}
 	}
 	assign_defaults(\@tracks,$track_default);
@@ -149,7 +152,55 @@ sub make_tracks {
 
 }
 
-sub clear_undef {
+# Plot blocks can no longer be named. This is interfering from parsing
+# blocks which don't have parameters, but only <axes> or <backgrounds> blocks.
+
+sub make_tracks_v2 {
+	my ($conf_leaf,$track_default,$type) = @_;
+
+	my @tracks;
+	return @tracks if ! ref $conf_leaf->{plot};
+
+	for my $track (make_list($conf_leaf->{plot})) {
+
+		if(defined $track->{id}) {
+			$track->{__id} = $track->{id};
+		}
+		push @tracks, $track;
+	}
+	assign_auto_id(@tracks);
+
+	for my $t (@tracks) {
+		# assign type
+		if (! defined $t->{type}) {
+			$t->{type} ||= seek_parameter("type",$track_default);
+			$t->{type} ||= $type;
+			if (! defined $t->{type}) {
+				if(! defined $t->{axes} &&
+					 ! defined $t->{backgrounds}) {
+					fatal_error("track","no_type",join(",",get_track_types()),$t->{id},Dumper($t));
+				} else {
+					error("warning","track_has_no_type",$t->{id});
+				}
+			}
+		}
+		# assign file
+		$t->{file} ||= seek_parameter("file",$track_default);
+		if (! defined $t->{file}) {
+			if(! defined $t->{axes} &&
+				 ! defined $t->{backgrounds}) {
+				fatal_error("track","no_file",$t->{type},$t->{id},Dumper($t));
+			} else {
+				error("warning","track_has_no_file",$t->{id},$t->{type});
+			}
+		}
+	}
+	assign_defaults(\@tracks,$track_default);
+	#clear_undef_parameters(\@tracks);
+	return @tracks;
+}
+
+sub clear_undef_parameters {
 	my $tracks = shift;
 	for my $t (@$tracks) {
 		for my $param (keys %$t) {
@@ -162,17 +213,15 @@ sub assign_defaults {
 	my ($tracks,$track_default) = @_;
 	my $dir = fetch_conf("track_defaults");
 	return unless defined $dir;
-	my @types = uniq map {$_->{type}} @$tracks;
-	for my $type (sort @types) {
+	for my $track (@$tracks) {
+		my $type = $track->{type};
+		next unless defined $type;
 		my $conf_file = "$dir/$type.conf";
 		my $conf      = Circos::Configuration::loadconfiguration($conf_file,1);
-		for my $track (@$tracks) {
-			next unless $track->{type} eq $type;
-			for my $default (keys %$conf) {
-				if(! defined seek_parameter($default, $track, $track_default) ) {
-					printdebug_group("conf","default",$type,$default,$conf->{$default});
-					$track->{$default} = $conf->{$default};
-				}
+		for my $default (keys %$conf) {
+			if(! defined seek_parameter($default, $track, $track_default) ) {
+				printdebug_group("conf","default",$type,$default,$conf->{$default});
+				$track->{$default} = $conf->{$default};
 			}
 		}
 	}
@@ -193,6 +242,7 @@ sub assign_auto_id {
 
 sub track_type_ok {
 	my $type = shift;
+	return if ! defined $type;
 	return grep($type eq $_, @type_ok);
 }
 
