@@ -52,6 +52,8 @@ round_up
 is_num_equal
 is_num_notequal
 seek_parameter 
+seek_parameter_glob
+list_parameters
 is_hidden 
 not_defined_or_one
 defined_and_zero
@@ -89,6 +91,7 @@ use FindBin;
 use File::Spec::Functions;
 use Math::Round;
 #use Memoize;
+use List::MoreUtils qw(uniq);
 use Params::Validate qw(:all);
 use Regexp::Common qw(number);
 
@@ -355,6 +358,27 @@ sub is_comment {
   return $string =~ /^\s*\#/;
 }
 
+# -------------------------------------------------------------------
+sub seek_parameter_glob {
+  my ( $param_name, $rewrite_rx, @data_structs ) = @_;
+  my @target_string = split( /\|/, $param_name );
+	my @param_rx      = list_parameters(@data_structs);
+	my $params = {};
+	for my $param (@param_rx) {
+		if(grep($param =~ /$_/, @target_string)) {
+			my $value = seek_parameter($param,@data_structs);
+			if(defined $value) {
+				my $param_name = $param;
+				if($rewrite_rx) {
+					$param_name =~ s/$rewrite_rx//;
+				}
+				$params->{$param_name} = $value;
+			}
+		}
+	}
+	return $params;
+}
+
 # -------------------------------------------------------------------
 sub seek_parameter {
   # Given a parameter name and a list of hash references (or list
@@ -374,6 +398,7 @@ sub seek_parameter {
   # value of x or y, whichever is seen first is returned
   # seek_parameter("x|y",$hash,$anotherhash);
   my ( $param_name, @data_structs ) = @_;
+	return seek_parameter_glob($param_name, @data_structs) if $param_name =~ /[*]/;
   my @target_string = split( /\|/, $param_name );
 	my $not_def_ok = 1;
   start_timer("parameter_seek");
@@ -412,6 +437,39 @@ sub seek_parameter {
   return undef;
 }
 
+# -------------------------------------------------------------------
+sub list_parameters {
+  # List all populated parameters.
+	#
+  # list_parameters($hash);
+  # list_parameters($hash,$anotherhash);
+  my ( @data_structs ) = @_;
+	my @params = ();
+  start_timer("parameter_seek");
+	for my $struct (@data_structs) {
+		if ( ref($struct) eq "ARRAY" ) {
+			for my $substruct (@$struct) {
+				if (ref $substruct->{param} eq "HASH") {
+					push @params, grep(defined $substruct->{param}{$_}, keys %{$substruct->{param}});
+				}
+				if (ref $substruct eq "HASH") {
+					push @params, grep(defined $substruct->{$_}, keys %$substruct);
+				}
+			}
+		} elsif ( ref($struct) eq "HASH" ) {
+			if (ref $struct->{param} eq "HASH") {
+				push @params, grep(defined $struct->{param}{$_}, keys %{$struct->{param}});
+			}
+			if (ref $struct eq "HASH") {
+				push @params, grep(defined $struct->{$_}, keys %$struct);
+			}
+		}
+	}
+  stop_timer("parameter_seek");
+	return uniq @params;
+}
+
+
 sub is_hidden {
 	my @datapath   = @_;
 	my $show_state = seek_parameter("show", @datapath);
@@ -439,7 +497,6 @@ sub locate_file {
 		%params = @_;
 	}
 
-	# look for the file in various directories
 	# v0.63 added configuration directory to dir_1
 	my @dir_1 = grep($_,getcwd,Circos::Configuration::fetch_conf("configdir"),$FindBin::RealBin);
 	my @dir_2 = qw(. .. ../.. ../../..);
@@ -448,6 +505,8 @@ sub locate_file {
 	my $file   = $params{file};
 	# remove any comma-delimited elements from the file
 	$file =~ s/,.*//;
+	# remove any trailing rx brackets from file
+	$file =~ s/\(.+?\)$//;
 	printdebug_group("io","locating file",$file,"role",$params{name});
 
 	if (! defined $file) {
